.. LexicalRichness documentation master file, created by
   sphinx-quickstart on Tue Aug 16 21:35:10 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. toctree::
   :maxdepth: 2

.. include:: usefullinks.rst

.. include:: ../README.rst

.. include:: details.rst

.. include:: docstring_docs.rst
